Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(171)

Unified Diff: src/interpreter/bytecode-array-builder.h

Issue 2336643002: [Interpreter] Move context chain search loop to handler (Closed)
Patch Set: Address comments Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/interpreter/bytecode-array-builder.h
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h
index 833e26b5a2e6896a9c63eecb34207c472fe6ba4f..7a1e7ac5682eeef628abe3cde50b3d2e300a7ada 100644
--- a/src/interpreter/bytecode-array-builder.h
+++ b/src/interpreter/bytecode-array-builder.h
@@ -94,11 +94,15 @@ class BytecodeArrayBuilder final : public ZoneObject {
int feedback_slot,
LanguageMode language_mode);
- // Load the object at |slot_index| in |context| into the accumulator.
- BytecodeArrayBuilder& LoadContextSlot(Register context, int slot_index);
+ // Load the object at |slot_index| at |depth| in |context| into the
Michael Starzinger 2016/09/13 09:53:08 nit: "... at |depth| in the context chain starting
Leszek Swirski 2016/09/13 10:17:51 Done.
+ // accumulator.
+ BytecodeArrayBuilder& LoadContextSlot(Register context, int slot_index,
+ int depth);
- // Stores the object in the accumulator into |slot_index| of |context|.
- BytecodeArrayBuilder& StoreContextSlot(Register context, int slot_index);
+ // Stores the object in the accumulator into |slot_index| at |depth| of
Michael Starzinger 2016/09/13 09:53:08 nit: Likewise.
Leszek Swirski 2016/09/13 10:17:51 Done, and done wherever else I added a depth param
+ // |context|.
+ BytecodeArrayBuilder& StoreContextSlot(Register context, int slot_index,
+ int depth);
// Register-accumulator transfers.
BytecodeArrayBuilder& LoadAccumulatorWithRegister(Register reg);

Powered by Google App Engine
This is Rietveld 408576698